# MosPy

MosPy is a cosmospy fork and aims to be a versatile transaction signing library for the whole cosmos ecosystem.

## Installation

Currently the only way to install mospy is by installing it directly from the github repository:
`python -m pip install git+https://github.com/ctrl-Felix/mospy.git `

## Support

When facing issues feel free to open a [github issue](https://github.com/ctrl-felix/mospy/issues) 
or reach out to the creators on the [Osmosis Discord](https://discord.gg/E2vkD6W8Xe).

